import type { App } from 'vue'
import type {
  RouteRecordRaw,
} from 'vue-router'
import {
  createRouter,
  createWebHashHistory,
} from 'vue-router'
import Layout from '@/layout/index.vue'

export const constantRoutes: Array<RouteRecordRaw> = [
  {
    path: '/404',
    name: '404',
    component: () => import('@/views/error/404.vue'),
    meta: {
      title: '404',
    },
  },
  {
    path: '/login',
    name: 'Login',
    component: () => import('@/views/login/index.vue'),
    meta: {
      title: '登录',
    },
  },
  {
    name: 'Layout',
    path: '/',
    component: Layout,
    redirect: '/conversation',
    children: [
      {
        name: 'Conversation',
        path: '/conversation',
        component: () => import('@/views/conversation/index.vue'),
        meta: {
          title: '会话',
        },
      },
      {
        name: 'ConversationNet',
        path: '/conversationNet',
        component: () => import('@/views/conversationNet/index.vue'),
        meta: {
          title: '联网会话',
        },
      },
      {
        name: 'TextToPicture',
        path: '/textToImage',
        component: () => import('@/views/textToImage/index.vue'),
        meta: {
          title: '文生图',
        },
      },
      {
        name: 'Role',
        path: '/Role',
        component: () => import('@/views/role/index.vue'),
        meta: {
          title: '角色',
        },
      },
      {
        name: 'Task',
        path: '/Task',
        component: () => import('@/views/task/index.vue'),
        meta: {
          title: '任务',
        },
      },
      {
        name: 'Repository',
        path: '/repository',
        component: () => import('@/views/repository/index.vue'),
        meta: {
          title: '知识库',
        },
      },
      {
        name: 'VisualAnalysis',
        path: '/visualAnalysis',
        component: () => import('@/views/visualAnalysis/index.vue'),
        meta: {
          title: '图像分析',
        },
      },
    ],
  },

]

export const router = createRouter({
  history: createWebHashHistory(import.meta.env.VITE_GLOB_BASE_URL),
  routes: constantRoutes,
})

export function setupRouter(app: App) {
  app.use(router)
}
