import { defineStore } from 'pinia'
import type { ConversationData, MessageStoreType } from './index.d'
import { MessageStatusEnum } from '@/enums/messageEnum'
import type { MessageItem } from '@/components/AppMessage/index.d'

export const useMessageStore = defineStore('useMessageStore', {
  state: (): MessageStoreType => {
    return {
      messageStatus: MessageStatusEnum.END,
      conversationData: undefined,
      topicKey: '',
      messageList: [],
    }
  },
  getters: {
    getMessageStatus(): MessageStatusEnum {
      return this.messageStatus
    },
    getConversationData(): ConversationData | undefined {
      return this.conversationData
    },
    getTopicKey(): string {
      return this.topicKey
    },
    getMessageList(): MessageItem[] {
      return this.messageList
    },
    getLastMessageList(): MessageItem {
      return this.messageList[this.messageList.length - 1]
    },
  },
  actions: {
    setMessageStatus(status: MessageStatusEnum): void {
      this.messageStatus = status
    },

    setConversationData(data: ConversationData | undefined) {
      this.conversationData = data
    },

    setMessagePushItem(item: MessageItem) {
      this.messageList.push(item)
    },

    setMessageUnshiftItem(item: MessageItem) {
      this.messageList.unshift(item)
    },

    setMessageLastItem(item: MessageItem) {
      this.messageList[this.messageList.length - 1] = item
    },

    setMessageLastPushItem(content: string) {
      this.messageList[this.messageList.length - 1].content = this.messageList[this.messageList.length - 1].content + content
    },

    setMessageClear() {
      this.messageList = []
    },

    setTopicKey(key: string) {
      this.topicKey = key
    },
  },

})
